@@ -51,7 +51,6 @@ healthcheck_port () {
 
     shift 1
     ports=""
-    puser=$(get_user_from_process $process)
     # First convert port to hex value. We need to 0-pad it in order to get the
     # right format (4 chars).
     for p in $@; do
@@ -69,14 +68,14 @@ healthcheck_port () {
     # would get all the connections existing in the same network namespace as the PID. Since we're using network=host, that would show *everything*.
     # the "join" method is weird, and fails if the array is empty.
     # Note: join comes from gawk's /usr/share/awk/join.awk and has some weird parameters.
-    sockets=$(awk -i join -v m=${ports} '{IGNORECASE=1; if ($2 ~ m || $3 ~ m) {output[counter++] = $10} } END{if (length(output)>0) {print join(output, 0, length(output)-1, "|")}}' /proc/net/{tcp,udp})
+    sockets=$(awk -i join -v m=${ports} '{IGNORECASE=1; if ($2 ~ m || $3 ~ m) {output[counter++] = $10} } END{if (length(output)>0) {print join(output, 0, length(output)-1, "|")}}' /proc/net/{tcp,udp,tcp6,udp6})
 
     # If no socket, just fail early
     test -z $sockets && exit 1
     match=0
     for pid in $(pgrep -f $process); do
         # Here, we check if a socket is actually associated to the process PIDs
-        match=$(( $match+$(sudo -u $puser find /proc/$pid/fd/ -ilname "socket*" -printf "%l\n" 2>/dev/null | grep -c -E "(${sockets})") ))
+        match=$(( $match+$(find /proc/$pid/fd/ -ilname "socket*" -printf "%l\n" 2>/dev/null | grep -c -E "(${sockets})") ))
         test $match -gt 0 && exit 0 # exit as soon as we get a match
     done
     exit 1 # no early exit, meaning failure.
@@ -128,7 +127,7 @@ get_url_from_vhost () {
         server_name=$(awk '/ServerName/ {print $2}' $vhost_file)
         ssl_enabled=$(awk '/SSLEngine/ {print $2}' $vhost_file)
         bind_port=$(grep -h "<VirtualHost .*>" $vhost_file | sed 's/<VirtualHost .*:\(.*\)>/\1/')
-        wsgi_alias=$(awk '/WSGIScriptAlias/ {print $2}' $vhost_file)
+        wsgi_alias=$(awk '/WSGIScriptAlias / {print $2; exit}' $vhost_file)
         proto=http
         if [[ $ssl_enabled == "on" ]]; then
             proto=https
