@@ -13,6 +13,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import os
 
 #: The resource name used for package updates
 UPDATE_RESOURCE_NAME = 'UpdateDeployment'
@@ -90,6 +91,31 @@ PASSWORD_PARAMETER_NAMES = (
     'SwiftPassword',
 )
 
+DB_PASSWORD_PARAMETER_NAMES = (
+    'AodhPassword',
+    'BarbicanPassword',
+    'CeilometerPassword',
+    'CephGrafanaAdminPassword',
+    'CephDashboardAdminPassword',
+    'CinderPassword',
+    'DesignatePassword',
+    'GlancePassword',
+    'GnocchiPassword',
+    'HeatPassword',
+    'HeatStackDomainAdminPassword',
+    'IronicPassword',
+    'LibvirtTLSPassword',
+    'KeystonePassword',
+    'ManilaPassword',
+    'MysqlClustercheckPassword',
+    'MysqlRootPassword',
+    'NeutronPassword',
+    'NovaPassword',
+    'NovajoinPassword',
+    'OctaviaPassword',
+    'PlacementPassword',
+)
+
 # List of passwords that should not be rotated by default using the
 # GeneratePasswordAction because they require some special handling
 DO_NOT_ROTATE_LIST = (
@@ -104,6 +130,9 @@ DO_NOT_ROTATE_LIST = (
     'CephManilaClientKey',
     'CephRgwKey',
     'HeatAuthEncryptionKey',
+    'MysqlClustercheckPassword',
+    'PacemakerRemoteAuthkey',
+    'PcsdPassword',
 )
 
 # The default version of the Identity API to set in overcloudrc.
@@ -152,3 +181,11 @@ INVENTORY_NETWORK_CONFIG_FILE = 'inventory-network-config.yaml'
 # Hard coded name in:
 #   tripleo_ansible/ansible_plugins/modules/tripleo_ovn_mac_addresses.py
 OVN_MAC_ADDR_NET_NAME = 'ovn_mac_addr_net'
+
+# Default directory for the overcloud deployment, where all inputs,
+# outputs and generated files are stored
+DEFAULT_WORKING_DIR_FORMAT = os.path.join(os.environ.get('HOME', '~/'),
+                                          'overcloud-deploy', '{}')
+
+# Format for password filename
+PASSWORDS_ENV_FORMAT = '{}-passwords.yaml'
