@@ -346,7 +346,16 @@ class TripleoInventory(object):
                 continue
 
             net_ip_map = role_net_ip_map[role_name]
-            ips = net_ip_map[self.host_network]
+            try:
+                ips = net_ip_map[self.host_network]
+            except KeyError:
+                LOG.warning(
+                    "Network key %s not found, check role data for %s",
+                    self.host_network,
+                    role_name
+                )
+                continue
+
             if not ips:
                 raise Exception("No IPs found for %s role on %s network" %
                                 (role_name, self.host_network))
@@ -686,6 +695,11 @@ class TripleoInventory(object):
         _vars.setdefault('ansible_connection', self.undercloud_connection)
         # see https://github.com/ansible/ansible/issues/41808
         _vars.setdefault('ansible_remote_tmp', '/tmp/ansible-${USER}')
+        # We don't want to let UC fail, especially when it comes to
+        # external tasks.
+        # See https://bugs.launchpad.net/tripleo/+bug/1960518 for context
+        _vars.setdefault('any_error_fatal', True)
+        _vars.setdefault('max_fail_percentage', 0)
 
         if self.ansible_python_interpreter:
             _vars.setdefault('ansible_python_interpreter',
