@@ -33,6 +33,10 @@ TEMPLATE_PATH = os.path.join(os.path.dirname(__file__),
 DEFAULTS_PATH = os.path.join(os.path.dirname(__file__),
                              '..', '..', '..', 'container-images',
                              'container_image_prepare_defaults.yaml')
+
+TEMPLATE_DIR_PATH = os.path.join(os.path.dirname(__file__),
+                                 '..', '..', '..', 'container-images')
+
 kb.init_prepare_defaults(DEFAULTS_PATH)
 KB_DEFAULT_TAG = kb.CONTAINER_IMAGES_DEFAULTS['tag']
 KB_DEFAULT_PREFIX = kb.CONTAINER_IMAGES_DEFAULTS['name_prefix']
@@ -260,6 +264,15 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'ceph_node_exporter_namespace',
                 'ceph_node_exporter_image',
                 'ceph_node_exporter_tag',
+                'ceph_haproxy_namespace',
+                'ceph_haproxy_image',
+                'ceph_haproxy_tag',
+                'ceph_keepalived_namespace',
+                'ceph_keepalived_image',
+                'ceph_keepalived_tag',
+                'pushgateway_namespace',
+                'pushgateway_image',
+                'pushgateway_tag',
                 ):
             if key in kb.CONTAINER_IMAGES_DEFAULTS:
                 expected[key] = kb.CONTAINER_IMAGES_DEFAULTS[key]
@@ -293,6 +306,15 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'ceph_node_exporter_namespace',
                 'ceph_node_exporter_image',
                 'ceph_node_exporter_tag',
+                'ceph_haproxy_namespace',
+                'ceph_haproxy_image',
+                'ceph_haproxy_tag',
+                'ceph_keepalived_namespace',
+                'ceph_keepalived_image',
+                'ceph_keepalived_tag',
+                'pushgateway_namespace',
+                'pushgateway_image',
+                'pushgateway_tag',
                 ):
             if key in kb.CONTAINER_IMAGES_DEFAULTS:
                 expected[key] = kb.CONTAINER_IMAGES_DEFAULTS[key]
@@ -364,7 +386,7 @@ class TestKollaImageBuilderTemplate(base.TestCase):
         files_dir = os.path.join(project_dir, 'container-images')
 
         oc_tmpl_file = os.path.join(files_dir, 'tripleo_containers.yaml.j2')
-        tmpl_builder = kb.KollaImageBuilder([oc_tmpl_file])
+        tmpl_builder = kb.KollaImageBuilder([oc_tmpl_file], files_dir)
 
         def ffunc(entry):
             if 'params' in entry:
@@ -378,7 +400,7 @@ class TestKollaImageBuilderTemplate(base.TestCase):
             rhel_containers=rhel_containers)
 
         oc_yaml_file = os.path.join(files_dir, 'tripleo_containers.yaml')
-        yaml_builder = kb.KollaImageBuilder([oc_yaml_file])
+        yaml_builder = kb.KollaImageBuilder([oc_yaml_file], files_dir)
         container_images = yaml_builder.load_config_files(
             yaml_builder.CONTAINER_IMAGES)
 
@@ -461,7 +483,8 @@ class TestPrepare(base.TestCase):
     def test_prepare_noargs(self, mock_insecure):
         self.assertEqual(
             {},
-            kb.container_images_prepare(template_file=TEMPLATE_PATH)
+            kb.container_images_prepare(template_file=TEMPLATE_PATH,
+                                        template_dir=TEMPLATE_DIR_PATH)
         )
 
     @mock.patch('tripleo_common.image.kolla_builder.'
@@ -480,6 +503,7 @@ class TestPrepare(base.TestCase):
             }},
             kb.container_images_prepare(
                 template_file=TEMPLATE_PATH,
+                template_dir=TEMPLATE_DIR_PATH,
                 output_env_file=CONTAINER_DEFAULTS_ENVIRONMENT,
                 output_images_file='container_images.yaml',
                 service_filter=['OS::TripleO::Services::NovaLibvirt'],
@@ -507,6 +531,7 @@ class TestPrepare(base.TestCase):
             }},
             kb.container_images_prepare(
                 template_file=TEMPLATE_PATH,
+                template_dir=TEMPLATE_DIR_PATH,
                 output_env_file=CONTAINER_DEFAULTS_ENVIRONMENT,
                 output_images_file='container_images.yaml',
                 includes=['libvirt'],
@@ -534,6 +559,7 @@ class TestPrepare(base.TestCase):
             }},
             kb.container_images_prepare(
                 template_file=TEMPLATE_PATH,
+                template_dir=TEMPLATE_DIR_PATH,
                 output_env_file=CONTAINER_DEFAULTS_ENVIRONMENT,
                 output_images_file='container_images.yaml',
                 includes=['libvirt'],
@@ -568,6 +594,7 @@ class TestPrepare(base.TestCase):
             }},
             kb.container_images_prepare(
                 template_file=TEMPLATE_PATH,
+                template_dir=TEMPLATE_DIR_PATH,
                 output_env_file=CONTAINER_DEFAULTS_ENVIRONMENT,
                 output_images_file='container_images.yaml',
                 service_filter=['OS::TripleO::Services::NovaApi'],
@@ -604,6 +631,7 @@ class TestPrepare(base.TestCase):
             }},
             kb.container_images_prepare(
                 template_file=TEMPLATE_PATH,
+                template_dir=TEMPLATE_DIR_PATH,
                 output_env_file=CONTAINER_DEFAULTS_ENVIRONMENT,
                 output_images_file='container_images.yaml',
                 service_filter=['OS::TripleO::Services::NovaApi'],
@@ -630,6 +658,7 @@ class TestPrepare(base.TestCase):
             }},
             kb.container_images_prepare(
                 template_file=TEMPLATE_PATH,
+                template_dir=TEMPLATE_DIR_PATH,
                 output_env_file=CONTAINER_DEFAULTS_ENVIRONMENT,
                 output_images_file='container_images.yaml',
                 service_filter=['OS::TripleO::Services::CephMon'],
@@ -655,6 +684,7 @@ class TestPrepare(base.TestCase):
             }},
             kb.container_images_prepare(
                 template_file=TEMPLATE_PATH,
+                template_dir=TEMPLATE_DIR_PATH,
                 output_env_file=CONTAINER_DEFAULTS_ENVIRONMENT,
                 output_images_file='container_images.yaml',
                 service_filter=[
@@ -688,6 +718,7 @@ class TestPrepare(base.TestCase):
             }},
             kb.container_images_prepare(
                 template_file=TEMPLATE_PATH,
+                template_dir=TEMPLATE_DIR_PATH,
                 output_env_file=CONTAINER_DEFAULTS_ENVIRONMENT,
                 output_images_file='container_images.yaml',
                 service_filter=[
@@ -716,6 +747,7 @@ class TestPrepare(base.TestCase):
 
         kb.container_images_prepare(
             template_file=TEMPLATE_PATH,
+            template_dir=TEMPLATE_DIR_PATH,
             output_env_file=CONTAINER_DEFAULTS_ENVIRONMENT,
             output_images_file='container_images.yaml',
             mapping_args={},
@@ -726,6 +758,7 @@ class TestPrepare(base.TestCase):
 
         kb.container_images_prepare(
             template_file=TEMPLATE_PATH,
+            template_dir=TEMPLATE_DIR_PATH,
             output_env_file=CONTAINER_DEFAULTS_ENVIRONMENT,
             output_images_file='container_images.yaml',
             mapping_args={"tag": "master"},
