@@ -290,6 +290,8 @@ class TestInventory(base.TestCase):
                     'ansible_host': 'localhost',
                     'ansible_python_interpreter': sys.executable,
                     'ansible_remote_tmp': '/tmp/ansible-${USER}',
+                    'any_error_fatal': True,
+                    'max_fail_percentage': 0,
                     'overcloud_keystone_url': 'xyz://keystone',
                     'overcloud_admin_password': 'theadminpw',
                     'plan': 'overcloud',
@@ -389,6 +391,8 @@ class TestInventory(base.TestCase):
                     'ansible_host': 'localhost',
                     'ansible_python_interpreter': sys.executable,
                     'ansible_remote_tmp': '/tmp/ansible-${USER}',
+                    'any_error_fatal': True,
+                    'max_fail_percentage': 0,
                     'undercloud_service_list': [
                         'tripleo_nova_compute',
                         'tripleo_heat_engine',
@@ -534,6 +538,8 @@ class TestInventory(base.TestCase):
                     'ansible_host': 'localhost',
                     'ansible_python_interpreter': 'foo',
                     'ansible_remote_tmp': '/tmp/ansible-${USER}',
+                    'any_error_fatal': True,
+                    'max_fail_percentage': 0,
                     'overcloud_keystone_url': 'xyz://keystone',
                     'overcloud_admin_password': 'theadminpw',
                     'plan': 'overcloud',
@@ -572,10 +578,10 @@ class TestInventory(base.TestCase):
                 'vars': {
                     'ansible_connection': 'local',
                     'ansible_host': 'localhost',
-                    'ansible_python_interpreter':
-                    sys.executable,
-                    'ansible_remote_tmp':
-                    '/tmp/ansible-${USER}',
+                    'ansible_python_interpreter': sys.executable,
+                    'ansible_remote_tmp': '/tmp/ansible-${USER}',
+                    'any_error_fatal': True,
+                    'max_fail_percentage': 0,
                     'overcloud_admin_password': 'theadminpw',
                     'overcloud_keystone_url': 'xyz://keystone',
                     'plan': 'overcloud',
@@ -981,6 +987,8 @@ class TestInventory(base.TestCase):
                          'ansible_host': 'localhost',
                          'ansible_python_interpreter': sys.executable,
                          'ansible_remote_tmp': '/tmp/ansible-${USER}',
+                         'any_error_fatal': True,
+                         'max_fail_percentage': 0,
                          'overcloud_admin_password': 'theadminpw',
                          'overcloud_keystone_url': 'xyz://keystone',
                          'plan': 'overcloud',
